//--------------------------------------------------------------
// File     : stm32_ub_stemwin.c
// Datum    : 14.12.2013
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : emWIN, UB_LCD_ST7783, UB_TOUCH_ADS7843
// Funktion : STemWin-Funktionen (von SEGGER)
//            Version 5.22 (vom 04.07.2013)
//            Quelle : www.segger.com
//
// Doku und Beispiele : www.segger.com/emwin-samples.html
//
// LIB      : das File : "lib_STemWin522_CM4_GCC.a" muss bei CoIDE
//            unter "Configuration/Link" mit dem Button "Add"
//            bei "Linked Libraries" hinzugefgt werden
//
// FPU      : Hardware FPU muss in CoIDE aktiviert werden
//
// MATH     : fuer einige emWin-Beispiele ist die "MATH.h" notwendig
//            dazu in CoIDE unter "Link/MiscControl" "-lm;" hinzufgen
//--------------------------------------------------------------


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32_ub_stemwin.h"


//--------------------------------------------------------------
// init vom Display/Touch und der emWin GUI
// Return_wert :
//  -> ERROR   , Fehler beim init
//  -> SUCCESS , alles OK
//--------------------------------------------------------------
ErrorStatus UB_STemWIN_init(void)
{
  RCC_ClocksTypeDef RCC_Clocks;

  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_CRC, ENABLE); // Wichtig !!

  //-----------------------------
  // init vom Systick (1ms)
  //-----------------------------
  RCC_GetClocksFreq(&RCC_Clocks);
  SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000);


  //-----------------------------
  // init vom Display
  //-----------------------------
  if(UB_LCD_Init()!=SUCCESS) {
    return(ERROR);
  }

  //-----------------------------
  // init vom Touch
  //-----------------------------
  if(UB_Touch_Init()!=SUCCESS) {
    return(ERROR);
  }

  //-----------------------------
  // init der emWIN GUI
  //-----------------------------
  if(GUI_Init()!=0) {
    return(ERROR);
  }

  return(SUCCESS);
}


//--------------------------------------------------------------
// Messung vom Touch
// (wird per Systick aufgerufen)
//--------------------------------------------------------------
void UB_STemWIN_updateTouch(void)
{
  GUI_PID_STATE TS_State;
  static uint8_t prev_state = 0;
  uint32_t TS_Orientation=0;  // zum test fix auf portrait

  // Touch auslesen (per Timer)

  if(TS_Orientation == 0)
  {
    TS_State.x = Touch_Data.pos.xp;
    TS_State.y = Touch_Data.pos.yp;
  }
  else
  {
    TS_State.y = Touch_Data.pos.xp;
    TS_State.x = 320 - Touch_Data.pos.yp;
  }
  TS_State.Pressed = (Touch_Data.status == TOUCH_PRESSED);

  if(prev_state != TS_State.Pressed )
  {
    prev_state = TS_State.Pressed;
    TS_State.Layer = 0;
    GUI_TOUCH_StoreStateEx(&TS_State);
  }
}


